.. _api:

API Docs
========

.. automodule:: flask_registry

.. autoclass:: Registry
   :members:

.. autoclass:: RegistryProxy
   :members:

.. autoclass:: RegistryBase
   :members:

.. autoclass:: RegistryError
   :members:

.. automodule:: flask_registry.registries.core

.. autoclass:: ListRegistry
   :members:

.. autoclass:: DictRegistry
   :members:

.. autoclass:: SingletonRegistry
   :members:

.. autoclass:: ImportPathRegistry
   :members:

.. autoclass:: ModuleRegistry
   :members:

.. automodule:: flask_registry.registries.appdiscovery

.. autoclass:: PackageRegistry
   :members:

.. autoclass:: ExtensionRegistry
   :members:

.. autoclass:: ConfigurationRegistry
   :members:

.. autoclass:: BlueprintAutoDiscoveryRegistry
   :members:

.. automodule:: flask_registry.registries.modulediscovery

.. autoclass:: ModuleDiscoveryRegistry
   :members:

.. autoclass:: ModuleAutoDiscoveryRegistry
   :members:

.. automodule:: flask_registry.registries.pkgresources

.. autoclass:: EntryPointRegistry
   :members:

.. autoclass:: PkgResourcesDirDiscoveryRegistry
   :members:


